==> cdktf-provider-google-2.0.22-sources.jar: com/hashicorp/cdktf/providers/google/ComputeSecurityPolicyAdvancedOptionsConfig.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-12T00:46:05.256Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.ComputeSecurityPolicyAdvancedOptionsConfig")
@software.amazon.jsii.Jsii.Proxy(ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeSecurityPolicyAdvancedOptionsConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * JSON body parsing. Supported values include: "DISABLED", "STANDARD".
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_parsing ComputeSecurityPolicy#json_parsing}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getJsonParsing() {
        return null;
    }

    /**
     * Logging level. Supported values include: "NORMAL", "VERBOSE".
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#log_level ComputeSecurityPolicy#log_level}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLogLevel() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeSecurityPolicyAdvancedOptionsConfig> {
        java.lang.String jsonParsing;
        java.lang.String logLevel;

        /**
         * Sets the value of {@link ComputeSecurityPolicyAdvancedOptionsConfig#getJsonParsing}
         * @param jsonParsing JSON body parsing. Supported values include: "DISABLED", "STANDARD".
         *                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_parsing ComputeSecurityPolicy#json_parsing}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jsonParsing(java.lang.String jsonParsing) {
            this.jsonParsing = jsonParsing;
            return this;
        }

        /**
         * Sets the value of {@link ComputeSecurityPolicyAdvancedOptionsConfig#getLogLevel}
         * @param logLevel Logging level. Supported values include: "NORMAL", "VERBOSE".
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#log_level ComputeSecurityPolicy#log_level}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logLevel(java.lang.String logLevel) {
            this.logLevel = logLevel;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeSecurityPolicyAdvancedOptionsConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeSecurityPolicyAdvancedOptionsConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeSecurityPolicyAdvancedOptionsConfig {
        private final java.lang.String jsonParsing;
        private final java.lang.String logLevel;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.jsonParsing = software.amazon.jsii.Kernel.get(this, "jsonParsing", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logLevel = software.amazon.jsii.Kernel.get(this, "logLevel", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.jsonParsing = builder.jsonParsing;
            this.logLevel = builder.logLevel;
        }

        @Override
        public final java.lang.String getJsonParsing() {
            return this.jsonParsing;
        }

        @Override
        public final java.lang.String getLogLevel() {
            return this.logLevel;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getJsonParsing() != null) {
                data.set("jsonParsing", om.valueToTree(this.getJsonParsing()));
            }
            if (this.getLogLevel() != null) {
                data.set("logLevel", om.valueToTree(this.getLogLevel()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.ComputeSecurityPolicyAdvancedOptionsConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy that = (ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy) o;

            if (this.jsonParsing != null ? !this.jsonParsing.equals(that.jsonParsing) : that.jsonParsing != null) return false;
            return this.logLevel != null ? this.logLevel.equals(that.logLevel) : that.logLevel == null;
        }

        @Override
        public final int hashCode() {
            int result = this.jsonParsing != null ? this.jsonParsing.hashCode() : 0;
            result = 31 * result + (this.logLevel != null ? this.logLevel.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-google-2.0.46-sources.jar: com/hashicorp/cdktf/providers/google/ComputeSecurityPolicyAdvancedOptionsConfig.java <==
package com.hashicorp.cdktf.providers.google;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-03T00:49:21.778Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.google.$Module.class, fqn = "@cdktf/provider-google.ComputeSecurityPolicyAdvancedOptionsConfig")
@software.amazon.jsii.Jsii.Proxy(ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ComputeSecurityPolicyAdvancedOptionsConfig extends software.amazon.jsii.JsiiSerializable {

    /**
     * json_custom_config block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_custom_config ComputeSecurityPolicy#json_custom_config}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig getJsonCustomConfig() {
        return null;
    }

    /**
     * JSON body parsing. Supported values include: "DISABLED", "STANDARD".
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_parsing ComputeSecurityPolicy#json_parsing}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getJsonParsing() {
        return null;
    }

    /**
     * Logging level. Supported values include: "NORMAL", "VERBOSE".
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#log_level ComputeSecurityPolicy#log_level}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getLogLevel() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<ComputeSecurityPolicyAdvancedOptionsConfig> {
        com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig jsonCustomConfig;
        java.lang.String jsonParsing;
        java.lang.String logLevel;

        /**
         * Sets the value of {@link ComputeSecurityPolicyAdvancedOptionsConfig#getJsonCustomConfig}
         * @param jsonCustomConfig json_custom_config block.
         *                         Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_custom_config ComputeSecurityPolicy#json_custom_config}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jsonCustomConfig(com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig jsonCustomConfig) {
            this.jsonCustomConfig = jsonCustomConfig;
            return this;
        }

        /**
         * Sets the value of {@link ComputeSecurityPolicyAdvancedOptionsConfig#getJsonParsing}
         * @param jsonParsing JSON body parsing. Supported values include: "DISABLED", "STANDARD".
         *                    Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#json_parsing ComputeSecurityPolicy#json_parsing}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder jsonParsing(java.lang.String jsonParsing) {
            this.jsonParsing = jsonParsing;
            return this;
        }

        /**
         * Sets the value of {@link ComputeSecurityPolicyAdvancedOptionsConfig#getLogLevel}
         * @param logLevel Logging level. Supported values include: "NORMAL", "VERBOSE".
         *                 Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/google/r/compute_security_policy#log_level ComputeSecurityPolicy#log_level}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder logLevel(java.lang.String logLevel) {
            this.logLevel = logLevel;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link ComputeSecurityPolicyAdvancedOptionsConfig}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public ComputeSecurityPolicyAdvancedOptionsConfig build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link ComputeSecurityPolicyAdvancedOptionsConfig}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements ComputeSecurityPolicyAdvancedOptionsConfig {
        private final com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig jsonCustomConfig;
        private final java.lang.String jsonParsing;
        private final java.lang.String logLevel;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.jsonCustomConfig = software.amazon.jsii.Kernel.get(this, "jsonCustomConfig", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig.class));
            this.jsonParsing = software.amazon.jsii.Kernel.get(this, "jsonParsing", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.logLevel = software.amazon.jsii.Kernel.get(this, "logLevel", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.jsonCustomConfig = builder.jsonCustomConfig;
            this.jsonParsing = builder.jsonParsing;
            this.logLevel = builder.logLevel;
        }

        @Override
        public final com.hashicorp.cdktf.providers.google.ComputeSecurityPolicyAdvancedOptionsConfigJsonCustomConfig getJsonCustomConfig() {
            return this.jsonCustomConfig;
        }

        @Override
        public final java.lang.String getJsonParsing() {
            return this.jsonParsing;
        }

        @Override
        public final java.lang.String getLogLevel() {
            return this.logLevel;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getJsonCustomConfig() != null) {
                data.set("jsonCustomConfig", om.valueToTree(this.getJsonCustomConfig()));
            }
            if (this.getJsonParsing() != null) {
                data.set("jsonParsing", om.valueToTree(this.getJsonParsing()));
            }
            if (this.getLogLevel() != null) {
                data.set("logLevel", om.valueToTree(this.getLogLevel()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-google.ComputeSecurityPolicyAdvancedOptionsConfig"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy that = (ComputeSecurityPolicyAdvancedOptionsConfig.Jsii$Proxy) o;

            if (this.jsonCustomConfig != null ? !this.jsonCustomConfig.equals(that.jsonCustomConfig) : that.jsonCustomConfig != null) return false;
            if (this.jsonParsing != null ? !this.jsonParsing.equals(that.jsonParsing) : that.jsonParsing != null) return false;
            return this.logLevel != null ? this.logLevel.equals(that.logLevel) : that.logLevel == null;
        }

        @Override
        public final int hashCode() {
            int result = this.jsonCustomConfig != null ? this.jsonCustomConfig.hashCode() : 0;
            result = 31 * result + (this.jsonParsing != null ? this.jsonParsing.hashCode() : 0);
            result = 31 * result + (this.logLevel != null ? this.logLevel.hashCode() : 0);
            return result;
        }
    }
}
